@@ -1,6 +1,6 @@
 /*
  *  Methods for encryption/security mechanisms for cryptmount
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -235,7 +235,7 @@ static int kmgcry_test_getalgos()
     CM_ASSERT_EQUAL(ERR_NOERROR,
         kmgcry_get_algos(&keyinfo, &cipher, &mode, &digest));
 
-    for (mapptr=map,cnt; mapptr->cipher!=-1; ++mapptr,++cnt) {
+    for (mapptr=map,cnt=0; mapptr->cipher!=-1; ++mapptr,++cnt) {
         keyinfo.cipheralg = (char*)mapptr->cname;
         keyinfo.digestalg = (char*)mapptr->dname;
         CM_ASSERT_EQUAL(ERR_NOERROR,
@@ -265,7 +265,7 @@ static void kmgcry_keybuilder(gcry_md_hd_t md_hand,
                     const unsigned char *pass, const size_t passlen,
                     unsigned char *ckey, const size_t ckeysz,
                     unsigned char *civ, const size_t civsz)
-    /* Generate cipher key & IV from password & salt (default variant) */
+    /*! Generate cipher key & IV from password & salt (default variant) */
 {   size_t kpos, ivpos, pos;
     unsigned char *buff;
 
@@ -298,7 +298,7 @@ static void kmgcryossl_keybuilder(gcry_md_hd_t md_hand,
                     const unsigned char *pass, const size_t passlen,
                     unsigned char *ckey, const size_t ckeysz,
                     unsigned char *civ, const size_t civsz)
-    /* Generate cipher key & IV from password & salt (a la OpenSSL) */
+    /*! Generate cipher key & IV from password & salt (a la OpenSSL) */
 {   size_t kpos, ivpos, pos;
     unsigned char *buff, *prev=NULL;
     unsigned cnt=0;
@@ -336,7 +336,7 @@ static void kmgcryossl_keybuilder(gcry_md_hd_t md_hand,
 static int kmgcry_initcipher(int cipher, int ciphermode, int digest,
             const unsigned char *salt, kmgcry_keybuilder_t keybuilder,
             const char *pass, size_t passlen, gcry_cipher_hd_t *hd)
-    /* Initialize block cipher from given password, salt & hashing scheme */
+    /*! Initialize block cipher from given password, salt & hashing scheme */
 {   gcry_md_hd_t md_hand;
     size_t ckeysz, cblksz, mdlen;
     unsigned char *ckey=NULL, *civ=NULL;
@@ -431,7 +431,7 @@ static int kmgcry_bind(bound_tgtdefn_t *bound, FILE *fp_key)
 
 
 static int kmgcryossl_bind(bound_tgtdefn_t *bound, FILE *fp_key)
-    /* OpenSSL-compatibility version of kmgcy_bind */
+    /*! OpenSSL-compatibility version of kmgcy_bind */
 {   keyinfo_t *keyinfo = &bound->tgt->key;
     char buff[32];
     int compat = 0;
@@ -470,7 +470,7 @@ static unsigned kmgcry_get_properties(const bound_tgtdefn_t *boundtgt)
 static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
             unsigned char **key, int *keylen, FILE *fp_key)
-    /* Extract key from libgcrypt-encrypted file */
+    /*! Extract key from libgcrypt-encrypted file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
@@ -567,7 +567,7 @@ static int kmgcry_get_key(bound_tgtdefn_t *boundtgt,
 static int kmgcry_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
-    /* Store key in libgcrypt-encrypted file */
+    /*! Store key in libgcrypt-encrypted file */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
@@ -629,7 +629,7 @@ static int kmgcry_put_key(bound_tgtdefn_t *boundtgt,
 static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
             unsigned char **key, int *keylen, FILE *fp_key)
-    /* Extract key from OpenSSL-compatible file via libgcrypt */
+    /*! Extract key from OpenSSL-compatible file via libgcrypt */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
@@ -723,7 +723,7 @@ static int kmgcryossl_get_key(bound_tgtdefn_t *boundtgt,
 static int kmgcryossl_put_key(bound_tgtdefn_t *boundtgt,
             const km_pw_context_t *pw_ctxt,
             const unsigned char *key, const int keylen, FILE *fp_key)
-    /* Store key in OpenSSL-compatible file via libgcrypt */
+    /*! Store key in OpenSSL-compatible file via libgcrypt */
 {   const keyinfo_t *keyinfo = &boundtgt->tgt->key;
     gcry_cipher_hd_t chd;
     char *passwd=NULL;
@@ -883,5 +883,5 @@ keymanager_t *kmgcry_gethandle()
 #endif  /* !AS_MODULE */
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
