@@ -1,6 +1,6 @@
 /*
  *  Methods for unit-testing utiltities for cryptmount
- *  (C)Copyright 2006-2011, RW Penney
+ *  (C)Copyright 2006-2012, RW Penney
  */
 
 /*
@@ -77,7 +77,9 @@ int cm_run_tests()
 {
     cm_tests_init();
 
+    ut_test_strings();
     ut_test_strops();
+    tb_test_expand();
     fs_test_blkgetsz();
     fs_test_splitopts();
     fs_test_entropy();
@@ -99,5 +101,5 @@ int _keep_ansi_pedantic_quiet = 0;
 #endif  /* TESTING */
 
 /*
- *  (C)Copyright 2006-2011, RW Penney
+ *  (C)Copyright 2006-2012, RW Penney
  */
