@@ -1,6 +1,6 @@
 /*
  *  cryptmount - a utility for user-level mounting of encrypted filesystems
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -746,7 +746,7 @@ static int do_keygen(const km_pw_context_t *pw_ctxt, bound_tgtdefn_t *boundtgt,
 
 
 static int do_safetynet()
-    /** Last-ditch attempt to umount/shutdown all targets currently mounted */
+    /** Last-ditch attempt to unmount/shutdown all targets currently mounted */
 {   tgtstat_t *all_tsts=NULL, *tst;
     char *devname=NULL;
     const char *old_ident=NULL;
@@ -1121,6 +1121,8 @@ int main(int argc, char *argv[])
     textdomain(PACKAGE);
 #endif
 
+    init_env_dictionary();
+
 #ifdef TESTING
     fprintf(stderr, "WARNING!!! cryptmount has been compiled for TESTING only - DO NOT INSTALL\n");
     pw_ctxt.argpasswd[0] = pw_ctxt.argpasswd[1] = NULL;
@@ -1185,7 +1187,9 @@ int main(int argc, char *argv[])
             case 'N':
                 pw_ctxt.argpasswd[1] = optarg; break;
             case 'T':
-                return cm_run_tests(); break;
+                eflag = cm_run_tests();
+                clear_env_dictionary();
+                return eflag; break;
 #endif
             case '?':
                 fprintf(stderr, "%s", _(USAGE_STRING));
@@ -1289,9 +1293,11 @@ int main(int argc, char *argv[])
     free_config(&tgttable);
     munlockall();
 
+    clear_env_dictionary();
+
     return eflag;
 }
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
