@@ -1,6 +1,6 @@
 /*
  *  Device-mapper utilities for cryptmount
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -32,6 +32,9 @@
 #if HAVE_NANOSLEEP
 #  include <time.h>
 #endif
+#if HAVE_LIBUDEV
+#  include <libudev.h>
+#endif
 
 #if defined(HAVE_LIBDEVMAP)
 #  include <libdevmapper.h>
@@ -249,7 +252,11 @@ int udev_settle()
     struct timespec delay;
 #endif
     int settling;
-    const double timeout = 5.0;
+    const double timeout = 10.0;
+#if HAVE_LIBUDEV
+    struct udev *udev_ctx;
+    struct udev_queue *udev_qu;
+#endif
 
     /* This routine mitigates apparent race-conditions
      * between udev events which may temporarily take ownership of
@@ -262,6 +269,12 @@ int udev_settle()
 
     time(&starttime);
 
+#if HAVE_LIBUDEV
+    udev_ctx = udev_new();
+    udev_selinux_init(udev_ctx);
+    udev_qu = udev_queue_new(udev_ctx);
+#endif
+
     /* Try to find location and type of udev event queue: */
     udev_mode = udev_queue_locations;
     while (udev_mode->is_file) {
@@ -271,7 +284,7 @@ int udev_settle()
 
 #if HAVE_NANOSLEEP
     delay.tv_sec = 0.0;
-    delay.tv_nsec = 2e7;
+    delay.tv_nsec = 100e6;
     inc = delay.tv_sec + delay.tv_nsec * 1e-9;
 #else
     inc = 1.0;
@@ -286,8 +299,10 @@ int udev_settle()
 #endif
         totdelay += inc;
 
+#if HAVE_LIBUDEV
+        settling = !udev_queue_get_queue_is_empty(udev_qu);
+#else
         settling = 0;
-
         if (udev_mode->is_file) {
             /* Current versions of udev place events in a single file: */
             settling |= (udev_queue_size(udev_mode->path) > 0);
@@ -295,8 +310,15 @@ int udev_settle()
             /* Older versions of udev use a directory of event files: */
             settling |= udev_active_dir(udev_mode->path, starttime, timeout);
         }
+#endif  /* HAVE_LIBUDEV */
     } while (settling && totdelay < timeout);
 
+#if HAVE_LIBUDEV
+    udev_queue_unref(udev_qu);
+    udev_selinux_exit(udev_ctx);
+    udev_unref(udev_ctx);
+#endif
+
     return settling;
 }
 
@@ -351,5 +373,5 @@ int udev_active_dir(const char *path, time_t starttime, double timeout)
 }
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
