@@ -1,6 +1,6 @@
 /*
  *  declarations for config-table & mount-table utilities for cryptmount
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -36,6 +36,8 @@ typedef struct tgtstat
 } tgtstat_t;
 
 
+void init_env_dictionary();
+void clear_env_dictionary();
 struct tgtdefn *alloc_tgtdefn(const struct tgtdefn *prototype);
 const struct tgtdefn *get_tgtdefn(const struct tgtdefn *head,
                                 const char *ident);
@@ -55,5 +57,5 @@ void free_tgtstatus(tgtstat_t *tstat);
 #endif  /* _TABLES_H */
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
