@@ -1,6 +1,6 @@
 /*
  *  Miscellaneous utility functions for cryptmount
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -43,6 +43,143 @@
 #endif
 
 
+cm_string_t *cm_str_init(char *val)
+    /** Construct a new string object from a plain char* string */
+{   cm_string_t *str;
+
+    if (val != NULL) {
+        const size_t len = strlen(val);
+        str = cm_str_alloc((len + 1));
+        memcpy(str->buffer, val, len + 1);
+        str->size = len;
+    } else {
+        str = cm_str_alloc(32);
+    }
+
+    return str;
+}
+
+
+cm_string_t *cm_str_alloc(size_t bufflen)
+    /** Construct a new string object of a specified size (including null) */
+{   cm_string_t *str;
+
+    str = (cm_string_t*)malloc(sizeof(cm_string_t));
+    str->buffer = (char*)malloc(bufflen);
+    if (bufflen > 0) str->buffer[0] = '\0';
+    str->bufflen = bufflen;
+    str->size = 0;
+
+    return str;
+}
+
+
+cm_string_t *cm_str_realloc(cm_string_t *str, size_t bufflen)
+    /** Ensure that string object can contain at least bufflen bytes */
+{
+    if (str->bufflen < bufflen) {
+        const size_t newbuff = 32 * (1 + (bufflen + 31) / 32);
+        str->buffer = (char*)realloc(str->buffer, newbuff);
+        str->bufflen = newbuff;
+    }
+
+    return str;
+}
+
+
+cm_string_t *cm_str_append(cm_string_t *str, const cm_string_t *addend)
+    /** Concatenate addend onto str, reserving additional memory as needed */
+{   const size_t totlen = (str->size + addend->size);
+
+    cm_str_realloc(str, (totlen + 1));
+
+    memcpy((void*)(str->buffer + str->size),
+            addend->buffer, addend->size + 1);
+    str->size = totlen;
+
+    return str;
+}
+
+
+cm_string_t *cm_str_append_char(cm_string_t *str, const char addend)
+    /** Concatenate addend onto str, reserving additional memory as needed */
+{
+    cm_str_realloc(str, (str->size + 2));
+
+    str->buffer[str->size] = addend;
+    ++str->size;
+    str->buffer[str->size] = '\0';
+
+    return str;
+}
+
+
+cm_string_t *cm_str_append_str(cm_string_t *str, const char *addend)
+    /** Concatenate addend onto str, reserving additional memory as needed */
+{   const size_t addlen = (addend != NULL ? strlen(addend) : 0);
+
+    cm_str_realloc(str, (str->size + addlen + 1));
+
+    memcpy((void*)(str->buffer + str->size), addend, addlen + 1);
+    str->size += addlen;
+
+    return str;
+}
+
+
+char *cm_str_strip(cm_string_t *str)
+    /** Extract character buffer from string object, and dispose of container */
+{   char *buff = str->buffer;
+
+    free((void*)str);
+
+    return buff;
+}
+
+
+void cm_str_free(cm_string_t *str)
+    /** Relinquish storage associated with string object */
+{
+    if (str == NULL) return;
+
+    free((void*)str->buffer);
+    free((void*)str);
+}
+
+
+#ifdef TESTING
+
+int ut_test_strings()
+    /* Check enhanced basic class */
+{   cm_string_t *str, *str2;
+
+    CM_TEST_START("String class methods");
+
+    str = cm_str_init("not much");
+    CM_ASSERT_STR_EQUAL("not much", str->buffer);
+
+    cm_str_append_char(str, ' ');
+    CM_ASSERT_STR_EQUAL("not much ", str->buffer);
+
+    cm_str_append_str(str, "to see");
+    CM_ASSERT_STR_EQUAL("not much to see", str->buffer);
+
+    str2 = cm_str_init(" here");
+    cm_str_append(str, str2);
+    CM_ASSERT_STR_EQUAL("not much to see here", str->buffer);
+
+    CM_ASSERT_EQUAL(20, str->size);
+    if (str->bufflen <= str->size) CM_TEST_FAIL();
+
+    cm_str_free(str);
+    cm_str_free(str2);
+
+    CM_TEST_OK();
+}
+
+#endif  /* TESTING */
+
+
 int cm_path(char **buff, const char *file)
     /* Create full pathname of config file */
 {   size_t pfxlen, sfxlen;
@@ -154,7 +291,7 @@ void *sec_realloc(void *ptr, size_t size)
         /* Copy (usable) part of old memory block into new: */
         oldsz = *(((size_t*)ptr) - 1);
         if (oldsz > size) oldsz = size;
-        memcpy((void*)(memarr + 1), (const void*)ptr, size);
+        memcpy((void*)(memarr + 1), (const void*)ptr, oldsz);
 
         /* Dispose of old memory block: */
         sec_free(ptr);
@@ -846,5 +983,5 @@ int ut_pwfort()
 #endif  /* TESTING */
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
