@@ -1,6 +1,6 @@
 /*
  *  Declarations for miscellaneous utilities for cryptmount
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
 
 /*
@@ -38,6 +38,25 @@ typedef struct km_pw_context {
 } km_pw_context_t;
 
 
+/**
+ *  Representation of a string of characters,
+ *  analogous to minimalistic std::string from C++
+ */
+typedef struct cm_string {
+    char *buffer;               /**< Storage area for characters */
+    size_t bufflen;             /**< Total space available within buffer */
+    size_t size;                /**< Current length of string (less null) */
+} cm_string_t;
+
+cm_string_t *cm_str_init(char *val);
+cm_string_t *cm_str_alloc(size_t bufflen);
+cm_string_t *cm_str_realloc(cm_string_t *str, size_t bufflen);
+cm_string_t *cm_str_append(cm_string_t *str, const cm_string_t *addend);
+cm_string_t *cm_str_append_char(cm_string_t *str, const char addend);
+cm_string_t *cm_str_append_str(cm_string_t *str, const char *addend);
+char *cm_str_strip(cm_string_t *str);
+void cm_str_free(cm_string_t *str);
+
 int cm_path(char **buff, const char *file);
 char *cm_strdup(const char *orig);
 int cm_strcasecmp(const char *s1, const char *s2);
@@ -107,5 +126,5 @@ static inline int cm_fwrite(const void *buff, size_t nbytes, FILE *stream) {
 #endif  /* _UTILS_H */
 
 /*
- *  (C)Copyright 2005-2011, RW Penney
+ *  (C)Copyright 2005-2012, RW Penney
  */
